INSERT INTO profile (testerid,name,pause) VALUES ('469','Andreas J. König','ANDK');
INSERT INTO profile (testerid,name,pause) VALUES ('530','Dan Collins','DCOLLINS');
INSERT INTO profile (testerid,name,pause) VALUES ('38','Oliver Paukstadt','PSTADT');
INSERT INTO profile (testerid,name,pause) VALUES ('325','Yi Ma Mao','IMACAT');
INSERT INTO profile (testerid,name,pause) VALUES ('682','Jon Allen','JONALLEN');
INSERT INTO profile (testerid,name,pause) VALUES ('26','Jost Krieger','JOST');
INSERT INTO profile (testerid,name,pause) VALUES ('746','Ulrich Habel','RHAEN');
INSERT INTO profile (testerid,name,pause) VALUES ('8','Slaven Rezi&#x0107;','SREZIC');
INSERT INTO profile (testerid,name,pause) VALUES ('538','Serguei Trouchelle','STRO');
