<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en-gb" lang="en-gb">
<head>

[% body = PROCESS $SOURCE %]

[% 
    base_url   = 'stats.cpantesters.org' ;
    base_href  = 'http://stats.cpantesters.org' ;
    base_title = 'CPAN Testers Statistics' ;
%]

  <meta http-equiv="Content-Type"         content="text/html; charset=iso-8859-1" />
  <meta http-equiv="Content-Language"     content="en-gb" />
  <meta http-equiv="Content-Style-Type"   content="text/css" />
  <meta http-equiv="Content-Script-Type"  content="text/javascript" />

  <title>[% htmltitle || title | html %] : [% base_title %]</title>

  <meta name="title"       content="CPAN Testers Statistics" />
  <meta name="author"      content="Barbie" />
  <meta name="language"    content="en" />
  <meta name="keywords"    content="perl, cpan, test, testing, tester, testers, stat, statistics, reports, yacsmoke, smoke, smoker, black box, automated, automation" />
  <meta name="description" content="Analysis of reports submitted by the CPAN Testers community, who automatically black box test submissions to Perl's CPAN code repository" />

  <link rel="icon"          href="/favicon.ico" type="image/x-icon" />
  <link rel="shortcut icon" href="/favicon.ico" type="image/x-icon" /> 

  <link rel="stylesheet" type="text/css" media="screen,projection,print" href="/css/layout-min.css" />

  <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.9.1/jquery.min.js"></script>
  <script type="text/javascript" src="/js/sorttable.js"></script>

  [% INCLUDE "public/analytics.html" %]

<!--
  Site Layout, Design &amp; Development by Miss Barbell Productions
  Original CSS/XHTML Template Design by Wolfgang.

  Valid XHTML 1.0 - http://validator.w3.org/check?uri=referer
  Powered by LAMP (Linux, Apache, MySQL &amp; Perl) technologies.
  Produced by LABYRINTH, a state of the art Website Management System
  available from Miss Barbell Productions.
  For more information contact Barbie <barbie@missbarbell.co.uk>

  Smoke Box image copyright (c) Tyson Ibele 2004 (http://www.tysonibele.com/Main/gallery.htm)
-->

</head>

<body>
  <!-- Main Page Container -->
  <div class="page-container">

    <!-- For alternative headers START PASTE here -->

    <!-- A. HEADER -->      
    <div class="header">
      
      <!-- A.1 HEADER TOP -->
      <div class="header-middle">

        <!-- Sitelogo and sitename -->
        <div class="sitename">
          <h1><a href="/" title="Home">[% base_title %]</a></h1>
          <h3>[% base_url %]</h3>
          <h2><span class="timestamp1">August 1999</span> - <span class="timestamp1">[% THISDATE %]</span></h2>
        </div>
      </div>

        [% INCLUDE "public/box-sites.html" %]
    </div>

    <!-- B. MAIN -->
    <div class="break">

      <!-- A.4 HEADER BREADCRUMBS -->

      <!-- Breadcrumbs -->
      <div class="header-breadcrumbs">
        <div id="breadcrumbs">
        <ul>
          <li><a href="/" title="Home">Home</a></li>
          [% IF crumb3_name %]<li>[% IF crumb3_href %]<a href="[% crumb3_href %]" title="[% crumb3_name %]">[% crumb3_name %]</a>[% ELSE ; crumb3_name ; END %]</li>[% END %]
          [% IF crumb2_name %]<li>[% IF crumb2_href %]<a href="[% crumb2_href %]" title="[% crumb2_name %]">[% crumb2_name %]</a>[% ELSE ; crumb2_name ; END %]</li>[% END %]
          <li>[% crumb1_name %]</li>
        </ul>
        </div>
      </div>
    </div>

    <!-- For alternative headers END PASTE here -->

    <!-- B. MAIN -->
    <div class="main">
      <div class="main-inner">

      <!-- B.1 MAIN NAVIGATION -->
      <div class="main-navigation">

        <!-- Navigation Level 3 -->
        <div class="round-border-topright"></div>

        [% INCLUDE "public/box-menus.html" %]
        [% INCLUDE "public/quote.html" %]

      </div>
 
      <!-- B.1 MAIN CONTENT -->
      <div class="main-content">

        <div id="tooltip" class="update20110712">
          <p><strong>Upgrade Notice</strong></p>
          <p>The CPAN Testers Statistics site has been upgraded since you last accessed the site.
          Please press the F5 key or CTRL-R to refresh your browser cache to use the latest javascript and CSS files.</p>
        </div>

        <!-- Pagetitle -->
        <h1 class="pagetitle">[% title | html %]</h1>
        <div class="column1-unit">

          [% body %]

        </div>
        <hr class="clear-contentunit" />

      </div>
      <div class="blank"></div>
      </div>
    </div>
      
    <!-- C. FOOTER AREA -->      
    [% INCLUDE "public/footer.html" %]

  </div> 

  <p class="footnote"><a href="/terms.html" title="Terms &amp; Conditions">Terms &amp; Conditions</a></p>

  <script type="text/javascript" src="/js/iheart.js"></script>

</body>
</html>
