[% 
    title = 'Testers' ;
    box_sites = 1

    crumb1_name = 'Monthly Tester Stats' ;
%]

<h2>Testers By YEAR/MONTH (latest first)</h2>
<div class="boxer">
<table summary="Testers By YEAR/MONTH">
<tr><th class="top">DATE</th><th class="top">COUNT</th><th class="top">TOP TESTERS</th></tr>
[% FOREACH row = STATS %]
<tr>[% FOREACH col = row %]<td nowrap="nowrap">[% col %]</td>[% END %]</tr>
[% END %]
</table>
</div>
