[% IF found == 1 %]

<table class="matrix" summary="Report/Tester Info">
<tr><th>ID:     </th><td>[% id %]</td></tr>
<tr><th>GUID:   </th><td>[% guid %]</td></tr>
<tr><th>Subject:</th><td>[% subject %]</td></tr>
<tr><th>Address:</th><td>[% from %]</td></tr>
</table>

[% ELSIF found == 3 %]

<h2>ERROR</h2>
<p>No ID/GUID provided.</p>

[% ELSIF found == 4 %]

<h2>ERROR</h2>
<p>Invalid ID/GUID provided.</p>

[% ELSIF found == 9 %]

<h2>ERROR</h2>
<p>Sorry, the lookup is currently unavailable, please try again shortly.</p>

[% ELSE %]

<h2>ERROR</h2>
<p>Sorry, we were unable to retrieve that ID/GUID.</p>

[% END %]
