INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('104440','104440-ed372d00-b19f-3f77-b713-d32bba55d77f','unknown','LASTMONTH','kriegjcb@mi.ruhr-uni-bochum.de ((Jost Krieger))','AI-NeuralNet-Mesh','0.44','sun4-solaris','5.8.1','solaris','2.8','LASTMONTH061151','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('1396564','1396564-ed372d00-b19f-3f77-b713-d32bba55d77f','unknown','LASTMONTH','srezic@cpan.org','Acme-Buffy','1.5','i386-freebsd','5.5.5','freebsd','6.1-release','LASTMONTH022114','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('1544358','1544358-ed372d00-b19f-3f77-b713-d32bba55d77f','na','LASTMONTH','jj@jonallen.info ("JJ")','AI-NeuralNet-SOM','0.07','darwin-2level','5.8.3','darwin','7.9.0','LASTMONTH290833','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('1587804','1587804-ed372d00-b19f-3f77-b713-d32bba55d77f','na','LASTMONTH','jj@jonallen.info ("JJ")','AI-NeuralNet-SOM','0.07','darwin-2level','5.8.1','darwin','7.9.0','LASTMONTH030648','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('1717321','1717321-ed372d00-b19f-3f77-b713-d32bba55d77f','na','LASTMONTH','srezic@cpan.org','Abstract-Meta-Class','0.10','i386-freebsd','5.5.5','freebsd','6.1-release','LASTMONTH171653','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('1994346','1994346-ed372d00-b19f-3f77-b713-d32bba55d77f','unknown','LASTMONTH','srezic@cpan.org','AI-NeuralNet-SOM','0.02','i386-freebsd','5.6.2','freebsd','6.1-release','LASTMONTH062212','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2538246','2538246-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','LASTMONTH','bingos@cpan.org','Acme-CPANAuthors-French','0.06','i386-freebsd-thread-multi-64int','5.8.8','freebsd','6.2-release','LASTMONTH021014','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2549071','2549071-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','LASTMONTH','bingos@cpan.org','Acme-CPANAuthors-French','0.07','OpenBSD.i386-openbsd-thread-multi-64int','5.8.8','openbsd','4.2','LASTMONTH042025','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2603754','2603754-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','LASTMONTH','JOST@cpan.org ("Josts Smokehouse")','AI-NeuralNet-SOM','0.02','i86pc-solaris-64int','5.8.8 patch 34559','solaris','2.11','LASTMONTH122105','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2613077','2613077-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','LASTMONTH','srezic@cpan.org','Acme-Buffy','1.5','i386-freebsd','5.8.9','freebsd','6.1-release-p23','LASTMONTH132053','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2725989','2725989-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','LASTMONTH','stro@cpan.org','Acme-CPANAuthors-Canadian','0.0101','MSWin32-x86-multi-thread','5.10.0','MSWin32','5.00','LASTMONTH011303','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2959417','2959417-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','LASTMONTH','rhaen@cpan.org (Ulrich Habel)','Abstract-Meta-Class','0.11','MSWin32-x86-multi-thread','5.10.0','MSWin32','5.1','LASTMONTH301529','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2964284','2964284-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme','1.11111','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH010443','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2964285','2964285-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme-Buffy','1.5','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH010443','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2964537','2964537-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme-CPANAuthors-CodeRepos','0.080522','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH010609','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2964541','2964541-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme-CPANAuthors-Japanese','0.080522','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH010611','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2965412','2965412-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme-Brainfuck','1.1.1','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH010929','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2965930','2965930-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','AI-NeuralNet-BackProp','0.89','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH011103','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2965931','2965931-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','AI-NeuralNet-Mesh','0.44','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH011103','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966360','2966360-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','cpan@sourcentral.org ("Oliver Paukstadt")','AI-NeuralNet-SOM','0.07','s390x-linux','5.10.0','linux','2.6.16.60-0.31-default','THISMONTH010542','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966429','2966429-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','cpan@sourcentral.org ("Oliver Paukstadt")','Acme-BOPE','0.01','s390x-linux','5.8.8','linux','2.6.16.60-0.31-default','THISMONTH010558','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966541','2966541-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','cpan@sourcentral.org ("Oliver Paukstadt")','Acme-CPANAuthors-Canadian','0.0101','s390x-linux-thread-multi','5.8.8','linux','2.6.18-92.1.18.el5','THISMONTH010628','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966560','2966560-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','THISMONTH','cpan@sourcentral.org ("Oliver Paukstadt")','Acme-CPANAuthors-French','0.07','s390x-linux-thread-multi','5.8.8','linux','2.6.18-92.1.18.el5','THISMONTH010635','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966567','2966567-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','cpan@sourcentral.org ("Oliver Paukstadt")','Acme-CPANAuthors-CodeRepos','0.080522','s390x-linux','5.10.0','linux','2.6.16.60-0.31-default','THISMONTH010638','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2966771','2966771-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','AEAE','0.02','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH011502','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2967174','2967174-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','AOL-TOC','0.340','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH011645','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2967432','2967432-ed372d00-b19f-3f77-b713-d32bba55d77f','fail','THISMONTH','andreas.koenig.gmwojprw@franz.ak.mind.de','Acme-CPANAuthors-French','0.07','x86_64-linux','5.10.0','linux','2.6.24-1-amd64','THISMONTH011038','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2967647','2967647-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','imacat@mail.imacat.idv.tw','Acme-Anything','0.02','x86_64-linux-thread-multi-ld','5.10.0','linux','2.6.24-etchnhalf.1-amd64','THISMONTH011830','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2969433','2969433-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','CPAN.DCOLLINS@comcast.net','Abstract-Meta-Class','0.11','i686-linux-thread-multi','5.10.0','linux','2.6.24-19-generic','THISMONTH010115','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2969661','2969661-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','CPAN.DCOLLINS@comcast.net','Abstract-Meta-Class','0.11','i686-linux-thread-multi','5.10.0','linux','2.6.24-19-generic','THISMONTH010303','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2969663','2969663-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','CPAN.DCOLLINS@comcast.net','Abstract-Meta-Class','0.11','i686-linux-thread-multi','5.10.0','linux','2.6.24-19-generic','THISMONTH010303','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2970367','2970367-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','CPAN.DCOLLINS@comcast.net','Abstract-Meta-Class','0.11','i686-linux-thread-multi','5.11.0 patch GitLive-blead-163-g28b1dae','linux','2.6.24-19-generic','THISMONTH010041','2');
INSERT INTO cpanstats ( id, guid, state, postdate, tester, dist, version, platform, perl, osname, osvers, fulldate, type) VALUES ('2975969','2975969-ed372d00-b19f-3f77-b713-d32bba55d77f','pass','THISMONTH','rhaen@cpan.org (Ulrich Habel)','Acme-CPANAuthors-Japanese','0.090101','MSWin32-x86-multi-thread','5.10.0','MSWin32','5.1','THISMONTH021220','2');
