[% 
    title = 'CPAN Submission Rates' ;
    box_sites = 1

    crumb1_name = 'CPAN Submission Rates' ;
%]

<h2>Contents</h2>
<ul class="contents">
<li><a href="#submit1" title="CPAN Submissions - By Month">CPAN Submissions Rates By Month</a></li>
<li><a href="#submit2" title="CPAN Submissions - By Day of the Week">CPAN Submissions Rates By Day of the Week</a></li>
<li><a href="#submit3" title="CPAN Submissions - By Day of the Month">CPAN Submissions Rates By Day of the Month</a></li>
<li><a href="#submit4" title="CPAN Submissions - By Hour">CPAN Submissions Rates By Hour</a></li>
<li><a href="#raw"     title="Raw Data">Raw Data</a></li>
</ul>

<h2>Graphs</h2>
<h3 id="submit1">CPAN Submissions Rates By Month</h3>
<p><img src="/rates/submit1.png" alt="graph of CPAN Submissions Rates By Month" /></a></p>
<p>Exclusive excludes the current year, inclusive does.</p>
<h3 id="submit2">CPAN Submissions Rates By Day of the Week</h3>
<p><img src="/rates/submit2.png" alt="graph of CPAN Submissions Rates By Day of the Week" /></a></p>
<p>Exclusive excludes the current week, inclusive does.</p>
<h3 id="submit3">CPAN Submissions Rates By Day of the Month</h3>
<p><img src="/rates/submit3.png" alt="graph of CPAN Submissions Rates By Day of the Month" /></a></p>
<p>Exclusive excludes the current month, inclusive does.</p>
<h3 id="submit4">CPAN Submissions Rates By Hour</h3>
<p><img src="/rates/submit4.png" alt="graph of CPAN Submissions Rates By Hour" /></a></p>
<p>Exclusive excludes the current day, inclusive does.</p>

<h2 id="raw">Raw Data</h2>
<p>The raw data files are available here:</p>
<ul>
<li><a href="/rates/submit1.txt"  title="raw data for CPAN Submissions Rates By Month">CPAN Submissions Rates By Month</a></li>
<li><a href="/rates/submit2.txt"  title="raw data for CPAN Submissions Rates By Day of the Week">CPAN Submissions Rates By Day of the Week</a></li>
<li><a href="/rates/submit3.txt"  title="raw data for CPAN Submissions Rates By Day of the Month">CPAN Submissions Rates By Day of the Month</a></li>
<li><a href="/rates/submit4.txt"  title="raw data for CPAN Submissions Rates By Hour">CPAN Submissions Rates By Hour</a></li>
</ul>

<p>Graphs generated using the <a href="http://code.google.com/apis/chart/" title="Google Chart API">Google Chart API</a>.</p>
