INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','LBROCARD','Acme-Buffy','1.3','Acme-Buffy-1.3.tar.gz','1017236268');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','LBROCARD','Acme-Buffy','1.5','Acme-Buffy-1.5.tar.gz','1177769034');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','LBROCARD','Acme-Buffy','1.4','Acme-Buffy-1.4.tar.gz','1157733085');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','LBROCARD','Acme-Buffy','1.1','Acme-Buffy-1.1.tar.gz','990548103');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','LBROCARD','Acme-Buffy','1.2','Acme-Buffy-1.2.tar.gz','997617194');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.04','AI-NeuralNet-SOM-0.04.tar.gz','1182080003');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.06','AI-NeuralNet-SOM-0.06.tar.gz','1211531083');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.05','AI-NeuralNet-SOM-0.05.tar.gz','1200513667');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.01','AI-NeuralNet-SOM-0.01.tar.gz','1181057025');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.03','AI-NeuralNet-SOM-0.03.tar.gz','1181848391');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.07','AI-NeuralNet-SOM-0.07.tar.gz','1211612835');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','DRRHO','AI-NeuralNet-SOM','0.02','AI-NeuralNet-SOM-0.02.tar.gz','1181487612');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','VOISCHEV','AI-NeuralNet-SOM','0.01','AI-NeuralNet-SOM-0.01.tar.gz','970252633');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','VOISCHEV','AI-NeuralNet-SOM','0.02','AI-NeuralNet-SOM-0.02.tar.gz','970684892');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','INGY','Acme','1.11111','Acme-1.11111.tar.gz','1137626100');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','INGY','Acme','1.111','Acme-1.111.tar.gz','1079905156');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','INGY','Acme','1.11','Acme-1.11.tar.gz','1079870865');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','INGY','Acme','1.00','Acme-1.00.tar.gz','1079868743');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','INGY','Acme','1.1111','Acme-1.1111.tar.gz','1111906013');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ISHIGAKI','Acme-CPANAuthors-Japanese','0.071226','Acme-CPANAuthors-Japanese-0.071226.tar.gz','1198658704');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ISHIGAKI','Acme-CPANAuthors-Japanese','0.080522','Acme-CPANAuthors-Japanese-0.080522.tar.gz','1211389830');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ISHIGAKI','Acme-CPANAuthors-CodeRepos','0.080522','Acme-CPANAuthors-CodeRepos-0.080522.tar.gz','1211390902');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','SAPER','Acme-CPANAuthors-French','0.04','Acme-CPANAuthors-French-0.04.tar.gz','1221955693');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','SAPER','Acme-CPANAuthors-French','0.01','Acme-CPANAuthors-French-0.01.tar.gz','1221268256');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','SAPER','Acme-CPANAuthors-French','0.05','Acme-CPANAuthors-French-0.05.tar.gz','1222119306');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','SAPER','Acme-CPANAuthors-French','0.02','Acme-CPANAuthors-French-0.02.tar.gz','1221355420');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','SAPER','Acme-CPANAuthors-French','0.03','Acme-CPANAuthors-French-0.03.tar.gz','1221696260');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','SAPER','Acme-CPANAuthors-French','0.06','Acme-CPANAuthors-French-0.06.tar.gz','1225315698');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('upload','SAPER','Acme-CPANAuthors-French','0.07','Acme-CPANAuthors-French-0.07.tar.gz','1225662681');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('upload','ZOFFIX','Acme-CPANAuthors-Canadian','0.0101','Acme-CPANAuthors-Canadian-0.0101.tar.gz','1225664601');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','GARU','Acme-BOPE','0.01','Acme-BOPE-0.01.tar.gz','1222060546');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','JESSE','Acme-Buffy','1.3','Acme-Buffy-1.3.tar.gz','1065349193');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JETEVE','AEAE','0.02','AEAE-0.02.tar.gz','1139566791');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JETEVE','AEAE','0.01','AEAE-0.01.tar.gz','1138724959');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','JJORE','Acme-Anything','0.01','Acme-Anything-0.01.tar.gz','1186005823');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JJORE','Acme-Anything','0.02','Acme-Anything-0.02.tar.gz','1194827066');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-Mesh','0.43','AI-NeuralNet-Mesh-0.43.zip','968921615');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-BackProp','0.40','AI-NeuralNet-BackProp-0.40.zip','964250318');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-Mesh','0.31','AI-NeuralNet-Mesh-0.31.zip','967191936');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-BackProp','0.77','AI-NeuralNet-BackProp-0.77.zip','966067868');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-BackProp','0.42','AI-NeuralNet-BackProp-0.42.zip','964604318');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-Mesh','0.44','AI-NeuralNet-Mesh-0.44.zip','968964981');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-BackProp','0.89','AI-NeuralNet-BackProp-0.89.zip','966496907');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JBRYAN','AI-NeuralNet-Mesh','0.20','AI-NeuralNet-Mesh-0.20.zip','967009309');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','JALDHAR','Acme-Brainfuck','1.1.0','Acme-Brainfuck-1.1.0.tar.gz','1081229428');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JALDHAR','Acme-Brainfuck','1.1.1','Acme-Brainfuck-1.1.1.tar.gz','1081268735');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','JALDHAR','Acme-Brainfuck','1.0.0','Acme-Brainfuck-1.0.0.tar.gz','1031080554');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JHARDING','AOL-TOC','0.32','AOL-TOC-0.32.tar.gz','962207388');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JHARDING','AOL-TOC','0.340','AOL-TOC-0.340.tar.gz','966917420');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','JHARDING','AOL-TOC','0.33','AOL-TOC-0.33.tar.gz','962694743');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ADRIANWIT','Abstract-Meta-Class','0.09','Abstract-Meta-Class-0.09.tar.gz','1212364076');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.07','Abstract-Meta-Class-0.07.tar.gz','1212267288');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.04','Abstract-Meta-Class-0.04.tar.gz','1211589222');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ADRIANWIT','Abstract-Meta-Class','0.08','Abstract-Meta-Class-0.08.tar.gz','1212345949');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.01','Abstract-Meta-Class-0.01.tar.gz','1210001395');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.05','Abstract-Meta-Class-0.05.tar.gz','1211645127');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ADRIANWIT','Abstract-Meta-Class','0.10','Abstract-Meta-Class-0.10.tar.gz','1212962154');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ADRIANWIT','Abstract-Meta-Class','0.12','Abstract-Meta-Class-0.12.tar.gz','1224423414');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ADRIANWIT','Abstract-Meta-Class','0.11','Abstract-Meta-Class-0.11.tar.gz','1220826243');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.03','Abstract-Meta-Class-0.03.tar.gz','1210105676');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('backpan','ADRIANWIT','Abstract-Meta-Class','0.06','Abstract-Meta-Class-0.06.tar.gz','1211732184');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('upload','ADRIANWIT','Abstract-Meta-Class','0.13','Abstract-Meta-Class-0.13.tar.gz','1227483540');
INSERT INTO uploads ( type, author, dist, version, filename, released ) VALUES ('cpan','ISHIGAKI','Acme-CPANAuthors-Japanese','0.090101','Acme-CPANAuthors-Japanese-0.090101.tar.gz','1230748955');
