<h1>Testers Menu</h1>
<ul>
<li><a href="/index.html"         title="Home">Home</a></li>
<li><a href="/graphs.html"        title="Testing Trends">Testing Trends</a></li>
<li><a href="/testers.html"       title="Tester Leaderboard">Tester Leaderboard</a></li>
<li><a href="/interest.html"      title="Interesting Stats">Interesting Stats</a></li>
<li><a href="/perform.html"       title="Performance Stats">Performance Stats</a></li>
</ul>
<ul>
<li><a href="/cpanmail.html"      title="Find A Tester">Find A Tester</a></li>
<li><a href="/missing.html"       title="Missing In Action">Missing In Action</a></li>
</ul>

<h1>CPAN Menu</h1>
<ul>
<li><a href="/trends.html"        title="CPAN Trends">CPAN Trends</a></li>
<li><a href="/leadercpan.html"    title="CPAN Leaderboards">CPAN Leaderboards</a></li>
<li><a href="/statscpan.html"     title="Statistics of CPAN">Statistics of CPAN</a></li>
<li><a href="/rates.html"         title="Submission Rates">Submission Rates</a></li>
<li><a href="/uploads.html"       title="CPAN Uploads">CPAN Uploads</a></li>
</ul>

<h1>Monthly Stats</h1>
<ul>
<li><a href="/mreports.html"      title="Reports">Reports</a></li>
<li><a href="/mtesters.html"      title="Testers">Testers</a></li>
<li><a href="/mosname.html"       title="Operating Systems">Operating Systems</a></li>
<li><a href="/mplatforms.html"    title="Platforms">Platforms</a></li>
<li><a href="/mperls.html"        title="Perls">Perls</a></li>
</ul>

<h1>Matrices</h1>
<h2>By OS</h2>
<ul>
<li><a href="/osmatrix-month.html"      title="By OS - Official Perls (Last Month)">Official Perls (<span class="timestamp1">[% PREVMONTH %]</span>)</a></li>
<li><a href="/osmatrix.html"            title="By OS - Official Perls">Official Perls</a></li>
<li><a href="/osmatrix-full-month.html" title="By OS - All Perls (Last Month)">All Perls (<span class="timestamp1">[% PREVMONTH %]</span>)</a></li>
<li><a href="/osmatrix-full.html"       title="By OS - All Perls">All Perls</a></li>
</ul>
<h2>By Platform</h2>
<ul>
<li><a href="/pmatrix-month.html"       title="By Platform - Official Perls (Last Month)">Official Perls (<span class="timestamp1">[% PREVMONTH %]</span>)</a></li>
<li><a href="/pmatrix.html"             title="By Platform - Official Perls">Official Perls</a></li>
<li><a href="/pmatrix-full-month.html"  title="By Platform - All Perls (Last Month)">All Perls (<span class="timestamp1">[% PREVMONTH %]</span>)</a></li>
<li><a href="/pmatrix-full.html"        title="By Platform - All Perls">All Perls</a></li>
</ul>

<h1>Failures</h1>
<ul>
<li><a href="/wdists.html"        title="Counts">Counts</a></li>
<li><a href="/wpcent.html"        title="Percentage">Percentage</a></li>
<li><a href="/wdists-recent.html" title="Recent Counts">Recent Counts</a></li>
<li><a href="/wpcent-recent.html" title="Recent Percentage">Recent Percentage</a></li>
</ul>
<ul>
<li><a href="/noreports/all.html" title="No Reports">No Reports</a></li>
</ul>

<h1>Our Sponsors</h1>
<div id="iheart"></div>
