/*************************************************************/
/*   Design:   Multiflex-3 Update-7 / Layout-2               */
/*   File:     Text formats                                  */
/*-----------------------------------------------------------*/
/*   Author:   Wolfgang                                      */
/*   Date:     January 15, 2007                              */
/*   Homepage: wwww.1-2-3-4.info                             */
/*-----------------------------------------------------------*/
/*   License:  Fully open source without restrictions.       */
/*             Please keep footer credits with a link to     */
/*             Wolfgang (www.1-2-3-4.info). Thank you!       */
/*************************************************************/

/******************/
/*  MAIN SECTION  */
/******************/

/* MAIN NAVIGATION */
.nav3-grid {width:199px; border-bottom:solid 1px rgb(200,200,200);}
.nav3-grid dt a, .nav3-grid dt a:visited {display:block; min-height:2.0em /*Non-IE6*/; height:auto !important; height:2.0em /*IE6*/; line-height:2.0em; padding:0px 10px 0px 20px;  border-top: solid 1px rgb(200,200,200); text-decoration:none; color:rgb(70,122,167); font-weight:bold; font-size:120%;}
.nav3-grid dd a, .nav3-grid dd a:visited {display:block; min-height:1.7em /*Non-IE6*/; height:auto !important; height:1.7em /*IE6*/; line-height:1.7em; padding:0px 10px 0px 40px; border:none; font-weight:normal; text-decoration:none; color:rgb(70,122,167); font-size:120%;}
.nav3-grid dt a:hover, .nav3-grid dd a:hover {background-color:rgb(225,225,225); color:rgb(42,90,138); text-decoration:none;}

.nav3-bullet {width:120px; margin:10px 0 0 20px;}
.nav3-bullet dt a, .nav3-bullet dt a:visited {line-height:2.0em; padding:0 0 0 10px; background:url(/images/layout/bg_bullet_full_1.gif) no-repeat 0px 50%; text-decoration:none; color:rgb(70,122,167); font-weight:bold; font-size:120%;}
.nav3-bullet dd a, .nav3-bullet dd a:visited {line-height:1.7em; margin:0 0 0 15px; padding:0 0 0 10px; background:url(/images/layout/bg_bullet_half_1.gif) no-repeat 0px 50%; text-decoration:none; color:rgb(70,122,167); font-weight:normal; font-size:120%;}
.nav3-bullet dt a:hover {background:url(/images/layout/bg_bullet_full_2.gif) no-repeat 0px 50%; text-decoration:underline; color:rgb(42,90,138);}
.nav3-bullet dd a:hover {background:url(/images/layout/bg_bullet_half_2.gif) no-repeat 0px 50%; text-decoration:underline; color:rgb(42,90,138);}

.nav3-nobullet {width:170px; margin:10px 0 0 20px;}
.nav3-nobullet dt a, .nav3-nobullet dt a:visited {line-height:2.0em; text-decoration:none; color:rgb(70,122,167); font-weight:bold; font-size:120%;}
.nav3-nobullet dd a, .nav3-nobullet dd a:visited {line-height:1.7em; margin:0 0 0 15px; text-decoration:none; color:rgb(70,122,167); font-weight:normal; font-size:120%;}
.nav3-nobullet dt a:hover, .nav3-nobullet dd a:hover {text-decoration:underline; color:rgb(42,90,138);}

.main-navigation .loginform {width:160px; margin:-10px 20px 0 20px;}
.main-navigation .loginform p {clear:both; margin:0; padding:0;}
.main-navigation .loginform fieldset {width:160px; border:none;}
.main-navigation .loginform label.top {float:left; width:125px; margin:0 0 2px 0; font-size:110%;}
.main-navigation .loginform label.right {float:left; width:125px; margin:5px 0 0 0; padding:0 0 0 3px; /*IE6*/; font-size:110%;}
.main-navigation .loginform input.field {width:158px; margin:0 0 5px 0; padding:0.1em 0 0.2em 0 !important /*Non-IE6*/; padding:0.2em 0 0.3em 0 /*IE6*/; border:solid 1px rgb(200,200,200); font-family:verdana,arial,sans-serif; font-size:110%;}
.main-navigation .loginform input.checkbox {float:left; margin:5px 0 0 0 !important /*Non-IE6*/; margin:2px 0 0 -3px /*IE6*/; border:none;}
.main-navigation .loginform input.button {float:left; width:5.0em; margin:10px 0 5px 0; padding:1px; background:rgb(230,230,230); border:solid 1px rgb(150,150,150); text-align:center; font-family:verdana,arial,sans-serif; color:rgb(150,150,150); font-size:110%;}
.main-navigation .loginform input.button:hover {cursor:pointer; border:solid 1px rgb(80,80,80); background:rgb(220,220,220); color:rgb(80,80,80);}

.main-navigation .searchform {width:160px; margin:0 20px 0 20px;}
.main-navigation .searchform fieldset {border:none;}
.main-navigation .searchform input.field {float:left; width:158px; padding:0.1em 0 0.2em 0 !important /*Non-IE6*/; padding:0.2em 0 0.3em 0 /*IE6*/; border:1px solid rgb(200,200,200); font-family:verdana,arial,sans-serif; font-size:120%;}
.main-navigation .searchform input.button {float:left; width:3.0em; margin-top: 0.5em; padding:1px; background:rgb(230,230,230); border:solid 1px rgb(150,150,150); text-align:center; font-family:verdana,arial,sans-serif; color:rgb(150,150,150); font-size:120%;}
.main-navigation .searchform input.button:hover {cursor:pointer; border:solid 1px rgb(80,80,80); background:rgb(220,220,220); color:rgb(80,80,80);}

.main-navigation h1.first {clear:both; margin:0px; padding:4px 20px 3px 20px; background-color:rgb(190,190,190); font-family:"trebuchet ms",arial,sans-serif; color:rgb(255,255,255); font-weight:bold; font-size:150%;}
.main-navigation h1 {clear:both; margin:30px 0 20px 0; padding:4px 20px 3px 20px; background:rgb(190,190,190); font-family:"trebuchet ms",arial,sans-serif; color:rgb(255,255,255); font-weight:bold; font-size:150%;}
.main-navigation h2 {clear:both; margin:10px 10px 2px 20px; font-family:"trebuchet ms",arial,sans-serif; color:rgb(100,100,100); font-weight:bold; font-size:110%;}
.main-navigation select {clear:both; margin:2px 10px 5px 20px; font-family:"trebuchet ms",arial,sans-serif; color:rgb(100,100,100); font-weight:bold; font-size:100%;}
.main-navigation h3 {clear:both; margin:10px 10px 5px 20px; color:rgb(80,80,80); font-weight:bold; font-size:110%;} /* Note: h2 not existent, to make identical to formats for main-navigation for easier exchange */
.main-navigation p {clear:both; margin:0 10px 10px 20px; color:rgb(80,80,80); line-height:1.3em; font-size:110%;}
.main-navigation p.center {text-align:center;}
.main-navigation p.right {text-align:right;}

.main-navigation ul {list-style:none; margin:0.5em 10px 1.0em 20px;}
.main-navigation ul li {margin:5px 0 0.2em 2px; padding:0px 0px 0 11px; background:url(/images/layout/bg_bullet_full_1.gif) no-repeat 0 0.4em; line-height:1.2em; font-size:110%;}
.main-navigation ol {margin:0.5em 10px 1.0em 40px !important /*Non-IE6*/; margin:0.5em 10px 1.0em 45px /*IE6*/;}
.main-navigation ol li {list-style-position:outside; margin:0 0 0.4em 0; font-size:110%;}

/* MAIN CONTENT */
.main-content h1.pagetitle {margin:0 0 0.4em 0; padding:0 0 2px 0; border-bottom:solid 7px rgb(225,225,225); font-family:"trebuchet ms",arial,sans-serif; color:rgb(100,100,100); font-weight:bold; font-size:220%;}
.main-content h1.block {clear:both; margin:1.0em 0 0em 0; padding:2px 0 2px 2px; background:rgb(190,190,190); font-family:"trebuchet ms",arial,sans-serif; color:rgb(255,255,255); font-weight:bold; font-size:220%;}
.main-content h1 {clear:both; margin:1.0em 0 0.5em 0; font-family:"trebuchet ms",arial,sans-serif; color:#0000FF; font-weight:normal; font-size:210%;}
.main-content h2 {clear:both; margin:1.0em 0 0.5em 0; font-family:"trebuchet ms",arial,sans-serif; color:#0000FF; font-weight:bold; font-size:170%;}
.main-content h3 {clear:both; margin:1.0em 0 0.5em 0; font-family:"trebuchet ms",arial,sans-serif; color:#0000FF; font-weight:normal; font-size:130%;}
.main-content h1.side {clear:none;}
.main-content h2.side {clear:none;}
.main-content h3.side {clear:none;}

.main-content h4 {margin:1.5em 0 1.0em 0; color:#0000FF; font-family:"trebuchet ms",arial,sans-serif; font-style:italic; font-size:120%;}
.main-content h5 {margin:1.5em 0 1.0em 0; color:#0000FF; font-family:"trebuchet ms",arial,sans-serif; font-style:italic; font-size:110%;}
.main-content h6 {margin:1.2em 0 0.2em 0; color:#0000FF; font-weight:bold; font-size:100%;}
.main-content p {margin:0 0 1.0em 0; line-height:1.5em; font-size:120%;}
.main-content p.center {text-align:center;}
.main-content p.right {text-align:right;}
.main-content p.details {clear:both; margin:-0.25em 0 1.0em 0; line-height:1.0em; font-size:110%;}
.main-content blockquote {clear:both; margin:0 30px 0.6em 30px; font-size:90%;}
.main-content pre {clear:both; margin:0 30px 0.6em 30px; font-size:100%;}

.main-content table {clear:both; width:630px; margin:0.5em 0 0.2em 0px; border-collapse:collapse; empty-cells:show; background-color:rgb(233,232,244);}
.main-content table th {height:3.5em; padding:0 7px 0 7px; empty-cells:show; background-color:rgb(175,175,175); text-align:left; color:rgb(255,255,255); font-weight:bold; font-size:110%;border:solid 2px rgb(255,255,255);}
.main-content table th.side {height:3.5em; padding:0 7px 0 7px; empty-cells:show; background-color:rgb(175,175,175); text-align:left; color:#000; font-weight:bold; font-size:110%;}
.main-content table th.top {height:3.5em; padding:0 7px 0 7px; empty-cells:show; background-color:rgb(175,175,175); text-align:left; color:rgb(255,255,255); font-weight:bold; font-size:110%;}
.main-content table th.odd {height:3.0em; padding:2px 20px 2px 7px; border-left:solid 2px rgb(255,255,255); border-right:solid 2px rgb(255,255,255); border-top:solid 2px rgb(255,255,255); border-bottom:solid 2px rgb(255,255,255); background-color:rgb(225,225,225); text-align:left; color:rgb(80,80,80); font-weight:bold; font-size:110%;}
.main-content table td {height:2.5em; padding:2px 7px 2px 7px; border-left:solid 2px rgb(255,255,255); border-right:solid 2px rgb(255,255,255); border-top:solid 2px rgb(255,255,255); border-bottom:solid 2px rgb(255,255,255); background-color:rgb(225,225,225); text-align:left; font-weight:normal; color:rgb(80,80,80); font-size:110%;}
.main-content table td.blank {height:2.5em; padding:2px 7px 2px 7px; border-left:solid 2px rgb(255,255,255); border-right:solid 2px rgb(255,255,255); border-top:solid 2px rgb(255,255,255); border-bottom:solid 2px rgb(255,255,255); background-color:rgb(225,225,225); text-align:left; font-weight:normal; color:rgb(80,80,80); font-size:110%;}
p.caption {clear:both; margin:0.5em 0 2.0em 20px; text-align:left; color:rgb(80,80,80); font-size:110%;}

.main-content ul {list-style:none; margin:0.5em 0 1.0em 0;}
.main-content ul li {margin:0 0 0.2em 2px; padding:0 0 0 12px; background:url(/images/layout/bg_bullet_full_1.gif) no-repeat 0 0.5em; line-height:1.4em; font-size:120%;}
.main-content ol {margin:0.5em 0 1.0em 20px !important /*Non-IE6*/; margin:0.5em 0 1.0em 25px /*IE6*/;}
.main-content ol li {list-style-position:outside; margin:0 0 0.2em 0; line-height:1.4em; font-size:120%;}
.main-content li li {font-size:100%;}
.main-content li li li {font-size:100%;}

.contactform {width:418px; margin:2.0em 0 0 0; padding:10px 10px 0 10px; border:solid 1px rgb(200,200,200); background-color:rgb(240,240,240);}
.contactform fieldset {padding:20px 0 0 0 !important /*Non-IE6*/; padding:0 /*IE6*/; margin:0 0 20px 0; border:solid 1px rgb(220,220,220);}
.contactform fieldset legend {margin:0 0 0 5px !important /*Non-IE*/; margin:0 0 20px 5px /*IE6*/; padding:0 2px 0 2px; color:rgb(80,80,80); font-weight:bold; font-size:130%;}
.contactform label.left {float:left; width:100px; margin:0 0 0 10px; padding:2px; font-size:110%;}
.contactform select.combo {width:175px; padding:2px; border:solid 1px rgb(200,200,200); font-family:verdana,arial,sans-serif; font-size:110%;}
.contactform input.field {width:275px; padding:2px; border:solid 1px rgb(200,200,200); font-family:verdana,arial,sans-serif; font-size:110%;}
.contactform textarea {width:275px; padding:2px; border:solid 1px rgb(200,200,200); font-family:verdana,arial,sans-serif; font-size:110%;}
.contactform input.button {float:right; width:9.0em; margin-right:20px; padding:1px !important /*Non-IE6*/; padding:0 /*IE6*/; background:rgb(230,230,230); border:solid 1px rgb(150,150,150); text-align:center; font-family:verdana,arial,sans-serif; color:rgb(150,150,150); font-size:110%;}
.contactform input.button:hover {cursor: pointer; border:solid 1px rgb(80,80,80); background:rgb(220,220,220); color:rgb(80,80,80);}

/********************/
/*  COMMON CLASSES  */
/********************/
/*
.main img {clear:both; float:left; margin:3px 10px 7px 0; padding:1px; border:1px solid rgb(150,150,150);}
.main img.center {clear:both; float:none; display:block; margin:0 auto; padding:1px; border:1px solid rgb(150,150,150);}
.main img.right {clear:both; float:right; margin:3px 0 7px 10px; padding:1px; border:1px solid rgb(150,150,150);}
*/
.main a {color:rgb(70,122,167); font-weight:bold; text-decoration:none;}
.main-content h1 a {color:rgb(70,122,167); font-weight:normal; text-decoration:none;}
.main a:hover {color:rgb(42,90,138); text-decoration:underline;}
.main a:visited {color:rgb(42,90,138);}

.main a img {border:solid 1px rgb(150,150,150);}
.main a:hover img {border:solid 1px rgb(220,220,220);}



.ud { border: 1px dashed #f00; padding: 5px; margin-bottom: 1em}
.ud p { color: #f00; }

.orange_buttons {
  float: right;
}

.orange_button {
  border:1px solid;
  border-color:#FC9 #630 #330 #F96;
  padding:0 3px;
  font:bold 10px verdana,sans-serif;
  color:#FFF;
  background:#F60;
  text-decoration:none;
  margin:0;
}

.emphasis {font-weight: bold;color: #0000ff;}

.ALL      { color: #e76300; }
.PASS     { color: #009900; }
.FAIL     { color: #990000; }
.UNKNOWN  { color: #999900; }
.NA       { color: #999900; }

.main-content table td.PASS     { background-color: #009900; color: #fff; }
.main-content table td.FAIL     { background-color: #990000; color: #fff; }
.main-content table td.UNKNOWN  { background-color: #999900; color: #fff; }
.main-content table td.NA       { background-color: #999900; color: #fff; }
.main-content table td.blank    { background-color: #ffffff; color: #fff; }
.main-content table td.CPAN     { background-color: #000000; color: #fff; }

.main-content table td.PASS     a { color: #fff; }
.main-content table td.FAIL     a { color: #fff; }
.main-content table td.UNKNOWN  a { color: #fff; }
.main-content table td.NA       a { color: #fff; }

.gPASS    { margin:0;padding:0; }
.gFAIL    { margin:0;padding:0; }
.gNA      { margin:0;padding:0; }
.gUNKNOWN { margin:0;padding:0; }

.oncpan   { margin:0;padding:0; }
.backpan  { margin:0;padding:0; }
.develrel { margin:0;padding:0; }
.official { margin:0;padding:0; }
.perldev  { margin:0;padding:0; }
.perlfull { margin:0;padding:0; }
.patch    { margin:0;padding:0; }
.regular  { margin:0;padding:0; }

.reportgraph { left: 10px; }

.main-navigation table { margin-left: 20px; }

a.tooltip, a.tooltip:visited {
	position: relative;
	color: #000;
}
 
a.tooltip span {
	display: none;
}
 
a.tooltip:hover {
	background-color: #ddf;
	color: #ddf;
}

a.tooltip:hover span {
	position: absolute;
	top: 10px;
	left: 30px;
	display: block;
	background: #000;
	width: 200px;
	padding: 4px;
	color: #fff;
} 

.users { margin: 5px 0px; border: 1px dashed #999; padding: 4px; }
.userbits { clear:both; margin: 0px; }
.username { font-weight:bold; font-size: 110%; }
.userinfo { clear:both; margin-left: 20px; width: 610px; }
.userinfo img { margin-left: 5px; margin-bottom: 5px; }

.main-navigation form { margin-left: 20px; }

.boxer {max-height: 600px;overflow:auto;}

.nav0 {z-index: 2; margin: 0px; font-size: 8pt; float: right; background-color:#000; width:100%;}
.nav0 ul {float:right; padding:4px 0;background-color:#000;}
.nav0 li {display:inline; list-style:none;margin:0;background-color:#000;padding:3px 5px; }
.nav0 li a {}
.nav0 a {text-decoration:none; font-weight: bold; }

.nav0 li.orange {border-right:5px solid #E76300;border-left:2px solid #000;}
.nav0 li.orange a {color:#fff;}
.nav0 li.orange a:hover {color:#E76300;}

.nav0 li.yellow {border-right:5px solid #FFFF00;border-left:2px solid #000;}
.nav0 li.yellow a {color:#fff;}
.nav0 li.yellow a:hover {color:#FFFF00;}

.nav0 li.blue {border-right:5px solid #0000FF;border-left:2px solid #000;}
.nav0 li.blue a {color:#fff;}
.nav0 li.blue a:hover {color:#0000FF;}

.nav0 li.cornblue {border-right:5px solid #6495ED;border-left:2px solid #000;}
.nav0 li.cornblue a {color:#fff;}
.nav0 li.cornblue a:hover {color:#6495ED;}

.nav0 li.cyan {border-right:5px solid #00FFFF;border-left:2px solid #000;}
.nav0 li.cyan a {color:#fff;}
.nav0 li.cyan a:hover {color:#00FFFF;}

.nav0 li.purple {border-right:5px solid #800080;border-left:2px solid #000;}
.nav0 li.purple a {color:#fff;}
.nav0 li.purple a:hover {color:#800080;}

.nav0 li.violet {border-right:5px solid #8A2BE2;border-left:2px solid #000;}
.nav0 li.violet a {color:#fff;}
.nav0 li.violet a:hover {color:#8A2BE2;}

.nav0 li.brown {border-right:5px solid #987654;border-left:2px solid #000;}
.nav0 li.brown a {color:#fff;}
.nav0 li.brown a:hover {color:#987654;}

.nav0 li.grey {border-right:5px solid #999;border-left:2px solid #000;}
.nav0 li.grey a {color:#fff;}
.nav0 li.grey a:hover {color:#999;}

.nav0 li.green {border-right:5px solid #00ee00;border-left:2px solid #000;}
.nav0 li.green a {color:#fff;}
.nav0 li.green a:hover {color:#00ee00;}

.nav0 li.teal {border-right:5px solid #008080;border-left:2px solid #000;}
.nav0 li.teal a {color:#fff;}
.nav0 li.teal a:hover {color:#008080;}

.nav0 li.red {border-right:5px solid #FD0E35;border-left:2px solid #000;}
.nav0 li.red a {color:#fff;}
.nav0 li.red a:hover {color:#FD0E35;}

.flat td {white-space:nowrap;}

.main-content table td.numbers { font-weight: bold; text-align: right; }

.main-content table td.none	    { background-color:#ddd; }
.main-content table td.some	    { background-color:#dfd; }
.main-content table td.more 	{ background-color:#9f9; }
.main-content table td.lots	    { background-color:#0f0; }
.main-content table th.totals	{ background-color:#000; color: #fff; }

#watcher { text-align: center; border: 1px solid #000; padding: 5px; }
#reportcount    { font-size: 24pt; color: #00f; }
#distrocount    { font-size: 18pt; color: #00f; }

#watcher table th { vertical-align: middle; text-align: right; font-size: 10pt; }
#watcher table td { vertical-align: middle; }
#watcher table td.centre { text-align: center; }

a img,
a:visited img,
a:hover img,
img { border: 1px rgb(225,225,225) solid; text-decoration: none; }

.footer strong  { color: #000; }
th.w100         { width: 15%; }
th.w200         { width: 25%; }

.footnote   { text-align: center; }
.footnote a { color:rgb(70,122,167); font-weight:bold; text-decoration:none; font-size: 0.7em; }

#socialbar {
    float: right;
    width: 400px; 
    border: 0px solid #0f0;
    margin-right: 10px;
    margin-top: -20px;
}

#facebook { width: 70px; float: right; border: 0px solid #f00; }
#gplus    { width: 70px; float: right; border: 0px solid #00f; }
#breadcrumbs  { float: left; }

#tooltip {
    background-color: #fff;
    color: #f00;
    width: 98%;

    padding: 5px; 
    border: dashed 1px #f00;
    margin-bottom: 20px;
}
#tooltip p  { margin-top: 2px; margin-bottom: 2px; }

.alert { color: #f00; }

.accessibility  { display: none }
.update20110712 { display: none }

.timestamp1 {}
.timestamp2 { font-weight: bold; }

#iheart a img,
#iheart a:hover img,
#iheart a:visited img { border:0 }
#iheart ul { list-style: none outside none; display: list-item; background-image: none; }
#iheart ul li { list-style: none outside none; display: list-item; background-image: none; }
