        <!-- Navigation Level 0 -->
        <div class="nav0">
          <ul>
          <li class="purple"  ><a href="http://blog.cpantesters.org"      title="CPAN Testers Blog"       >Blog</a></li>
          <li class="orange"  ><a href="http://www.cpantesters.org"       title="CPAN Testers Reports"    >Reports</a></li>
          <li class="violet"  ><a href="http://wiki.cpantesters.org"      title="CPAN Testers Wiki"       >Wiki</a></li>
          <li class="blue"    ><a href="http://stats.cpantesters.org"     title="CPAN Testers Statistics" >Statistics</a></li>
          <li class="yellow"  ><a href="http://pass.cpantesters.org"      title="CPAN Testers PASS Matrix">PASS Matrix</a></li>
          <li class="green"   ><a href="http://prefs.cpantesters.org"     title="CPAN Testers Preferences">Preferences</a></li>
          <li class="cornblue"><a href="http://metabase.cpantesters.org"  title="CPAN Testers Metabase"   >Metabase</a></li>
          <li class="cyan"    ><a href="http://devel.cpantesters.org"     title="CPAN Testers Development">Development</a></li>
          <li class="brown"   ><a href="http://deps.cpantesters.org"      title="CPAN Dependencies"       >CPAN Deps</a></li>
          <li class="grey"    ><a href="http://matrix.cpantesters.org"    title="CPAN Testers Matrix"     >CPAN Matrix</a></li>
          <li class="teal"    ><a href="http://analysis.cpantesters.org"  title="CPAN Testers Analysis"   >Analysis</a></li>
          <li class="red"     ><a href="http://admin.cpantesters.org"     title="CPAN Testers Admin"      >Admin</a></li>
          </ul>
        </div>
