<script type="text/javascript" src="http://www.google-analytics.com/urchin.js"></script>
<script type="text/javascript">
_uacct = "UA-1826389-9";
urchinTracker();
</script>

<script type="text/javascript">
function goThere(loc) {
  window.location.href=loc;
}
</script>
