INSERT INTO release_summary ( dist, version, id, guid ) VALUES ('Acme-Buffy','1.1','23576','00023576-b19f-3f77-b713-d32bba55d77f');
INSERT INTO release_summary ( dist, version, id, guid ) VALUES ('Acme-Buffy','1.2','31840','00031840-b19f-3f77-b713-d32bba55d77f');
INSERT INTO release_summary ( dist, version, id, guid ) VALUES ('Acme-Buffy','1.3','340624','00126021-b19f-3f77-b713-d32bba55d77f');
INSERT INTO release_summary ( dist, version, id, guid ) VALUES ('Acme-Buffy','1.4','355637','00355637-b19f-3f77-b713-d32bba55d77f');
INSERT INTO release_summary ( dist, version, id, guid ) VALUES ('Acme-Buffy','1.5','9314169','416fcf48-e41c-11df-bc7b-f3193444d33b');
