INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','AI-NeuralNet-Mesh','sun4-solaris','5.8.1','solaris');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Acme-Buffy','i386-freebsd','5.5.5','freebsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','AI-NeuralNet-SOM','darwin-2level','5.8.3','darwin');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','AI-NeuralNet-SOM','darwin-2level','5.8.1','darwin');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Abstract-Meta-Class','i386-freebsd','5.5.5','freebsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','AI-NeuralNet-SOM','i386-freebsd','5.6.2','freebsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Acme-CPANAuthors-French','i386-freebsd-thread-multi-64int','5.8.8','freebsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Acme-CPANAuthors-French','OpenBSD.i386-openbsd-thread-multi-64int','5.8.8','openbsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','AI-NeuralNet-SOM','i86pc-solaris-64int','5.8.8','solaris');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Acme-Buffy','i386-freebsd','5.8.9','freebsd');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Acme-CPANAuthors-Canadian','MSWin32-x86-multi-thread','5.10.0','MSWin32');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('LASTMONTH','Abstract-Meta-Class','MSWin32-x86-multi-thread','5.10.0','MSWin32');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-Buffy','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-CodeRepos','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-Japanese','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-Brainfuck','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','AI-NeuralNet-BackProp','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','AI-NeuralNet-Mesh','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','AI-NeuralNet-SOM','s390x-linux','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-BOPE','s390x-linux','5.8.8','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-Canadian','s390x-linux-thread-multi','5.8.8','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-French','s390x-linux-thread-multi','5.8.8','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-CodeRepos','s390x-linux','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','AEAE','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','AOL-TOC','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-French','x86_64-linux','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-Anything','x86_64-linux-thread-multi-ld','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Abstract-Meta-Class','i686-linux-thread-multi','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Abstract-Meta-Class','i686-linux-thread-multi','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Abstract-Meta-Class','i686-linux-thread-multi','5.10.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Abstract-Meta-Class','i686-linux-thread-multi','5.11.0','linux');
INSERT IGNORE passreports ( postdate, dist, platform, perl, osname) VALUES ('THISMONTH','Acme-CPANAuthors-Japanese','MSWin32-x86-multi-thread','5.10.0','MSWin32');
