[% 
    title = 'Testing Trends' ;
    box_sites = 1

    crumb1_name = 'Testing Trends' ;
%]

<h2>Contents</h2>
<ul class="contents">
<li><a href="#pcent1" title="Monthly Report Percentages">Monthly Report Percentages</a></li>
<li><a href="#stats1" title="Monthly Report Counts">Monthly Report Counts</a></li>
<li><a href="#stats2" title="Testers, Platforms and Perls">Testers, Platforms and Perls</a></li>
<li><a href="#stats3" title="Monthly Non-Passing Reports Counts">Monthly Non-Passing Reports Counts</a></li>
<li><a href="#stats4" title="Monthly Tester Fluctuations">Monthly Tester Fluctuations</a></li>
<li><a href="#raw"    title="Raw Data">Raw Data</a></li>
</ul>

<h2>Graphs</h2>
<p>Please click the graphs below to view the archived graphs for the respective statistics.</p>
<h3>Monthly Report Percentages</h3>
<p><a href="/graphs5.html" title="Graphs for Monthly Report Percentages"><img id="pcent1" src="/stats/pcent1.png" alt="CPAN Testing Statistics - Report Percentages" /></a></p>
<h3>Monthly Report Counts</h3>
<p><a href="/graphs1.html" title="Graphs for Monthly Report Counts"><img id="stats1" src="/stats/stats1.png" alt="CPAN Testing Statistics - Reports"    /></a></p>
<h3>Testers, Platforms and Perls</h3>
<p><a href="/graphs2.html" title="Graphs for Testers, Platforms and Perls"><img id="stats2" src="/stats/stats2.png" alt="CPAN Testing Statistics - Attributes" /></a></p>
<h3>Monthly Non-Passing Reports Counts</h3>
<p><a href="/graphs3.html" title="Graphs for Monthly Non-Passing Reports Counts"><img id="stats3" src="/stats/stats3.png" alt="CPAN Testing Statistics - Non-Passes" /></a></p>
<h3>Monthly Tester Fluctuations</h3>
<p><a href="/graphs4.html" title="Graphs for Monthly Tester Fluctuations"><img id="stats4" src="/stats/stats4.png" alt="CPAN Testing Statistics - Testers"    /></a></p>

<h2 id="raw">Raw Data</h2>
<p>The raw data files are available here:</p>
<ul>
<li><a href="/stats/pcent1.txt" title="Monthly Report Percentages">Monthly Report Percentages</a></li>
<li><a href="/stats/stats1.txt" title="Monthly Report Counts">Monthly Report Counts</a></li>
<li><a href="/stats/stats2.txt" title="Testers, Platforms and Perls">Testers, Platforms and Perls</a></li>
<li><a href="/stats/stats3.txt" title="Monthly Non-Passing Reports Counts">Monthly Non-Passing Reports Counts</a></li>
<li><a href="/stats/stats4.txt" title="Monthly Tester Fluctuations">Monthly Tester Fluctuations</a></li>
</ul>
<p>Graphs generated using the <a href="http://code.google.com/apis/chart/" title="Google Chart API">Google Chart API</a>.</p>
