<div id="socialbar">

  <div id="facebook">
    <div id="fb-root"></div>
    <script type="text/javascript">
        document.write('<' + 'fb:like send="false" layout="button_count" width="100" show_faces="false" font=""></fb:like>');
        var s = document.createElement('SCRIPT'), s1 = document.getElementsByTagName('SCRIPT')[0];
        s.type = 'text/javascript';
        s.async = true;
        s.src = 'http://connect.facebook.net/en_US/all.js#xfbml=1';
        s1.parentNode.insertBefore(s, s1);
    </script>
  </div>

  <div id="gplus">
    <script type="text/javascript" src="https://apis.google.com/js/plusone.js">
      {"parsetags": "explicit"}
    </script>
    <div id="plusone-div"></div>
    <script type="text/javascript">
        gapi.plusone.render("plusone-div",{"size": "medium", "count": "true"});
    </script>
  </div>

</div>