[% 

    htmltitle = 'Terms & Conditions' ;
    title = 'Terms & Conditions' ;
    box_sites = 1

    crumb1_name = 'Terms &amp; Conditions' ;
%]

<h2>Cookie Policy</h2>

<h3>EU Cookie Directive</h3>
<p>In order to comply with <strong><a title="Article 2 of Directive 2009/136/EC" href="http://eur-lex.europa.eu/LexUriServ/LexUriServ.do?uri=OJ:L:2009:337:0011:0036:EN:PDF">Article 2 of Directive 2009/136/EC</a></strong>, which amends the <strong><a title="E-Privacy Directive 2002/58/EC" href="http://eur-lex.europa.eu/LexUriServ/LexUriServ.do?uri=OJ:L:2002:108:0033:0050:EN:PDF">E-Privacy Directive 2002/58/EC</a></strong>, within the <strong><a title="EU Electronic Communications Framework" href="http://europa.eu/legislation_summaries/internal_market/single_market_services/l24216a_en.htm">EU Electronic Communications Framework (ECF)</a></strong>, all businesses must now make you aware of the use of cookies on their site.</p>

<h3>Our Cookie Usage</h3>
<p>This website uses cookies to enable us to improve the site usage. Our cookies fall into two categories; site usage and site analysis. Below are a list of the specifc cookies we use and what they are used for.</p>

<p>No Third Party cookies are used or set by the CPAN Testers Blog website.</p>
<p>Other useful links: <strong><a title="read more about cookies" href="http://www.allaboutcookies.org">http://www.allaboutcookies.org</a></strong>.</p>

<table id="infotable" border="0" summary="The Cookies We Use">
<tr>
  <th>Cookie&nbsp;Name</th><th>Category</th><th>Purpose</th>
</tr>
<tr>
  <td valign="top">_utma,<br />_utmc,<br />_utmz</td>
  <td valign="top">Analysis</td>
  <td>Google Analytics cookies. For more detailed information about how these cookies are used, please see the <a title="Google Analytics Cookie Guide" href="http://code.google.com/apis/analytics/docs/concepts/gaConceptsCookies.html">Google Analytics Cookie Guide</a>. Please note all Google Analytics cookies are considered <strong>First Party Cookies</strong> and are only used to process anonymous site usage for this domain.</td>
</tr>
</table>

<h3>Google Analytics</h3>
<p>This website uses Google Analytics, a web analytics service provided by Google, Inc. (&quot;Google&quot;). Google Analytics uses &quot;cookies&quot;, which are text files placed on your computer, to help the website analyze how users use the site. The information generated by the cookie about your use of the website (including your IP address) will be transmitted to and stored by Google on servers in the United States . Google will use this information for the purpose of evaluating your use of the website, compiling reports on website activity for website operators and providing other services relating to website activity and internet usage. Google may also transfer this information to third parties where required to do so by law, or where such third parties process the information on Google's behalf. Google will not associate your IP address with any other data held by Google. You may refuse the use of cookies by selecting the appropriate settings on your browser, however please note that if you do this you may not be able to use the full functionality of this website. By using this website, you consent to the processing of data about you by Google in the manner and for the purposes set out above.</p>

<h2>Links</h2>
<p>The inclusion of a link to an organisation's or individual's website does not constitute an endorsement or an approval by Peters of any product, service, policy or opinion of the organisation or individual. Peters is not responsible for the content of external websites.</p>

<h2>Privacy Policy</h2>
<p>For our complete Privacy Policy, please <a title="Privacy Policy" href="http://blog.cpantesters.org/pdf/privacypolicy.pdf">click here</a>.</p>
